        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>48</strong> miembros: 33 <strong>control</strong><br>0,1,2,4,6,7,8,11,12,13,14,17,20,21,22,24,26,27,28,29,32,33,36,38,41,42,44,45,46,47,48,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 18 <br>3,5,9,10,15,16,18,19,23,25,30,31,34,35,37,39,40,43';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>48</strong> miembros: 33 <strong>control</strong><br>0,1,2,4,6,7,8,11,12,13,14,17,20,21,22,24,26,27,28,29,32,33,36,38,41,42,44,45,46,47,48,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 18 <br>3,5,9,10,15,16,18,19,23,25,30,31,34,35,37,39,40,43';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>48</strong> miembros: 33 <strong>control</strong><br>0,1,2,4,6,7,8,11,12,13,14,17,20,21,22,24,26,27,28,29,32,33,36,38,41,42,44,45,46,47,48,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 18 <br>3,5,9,10,15,16,18,19,23,25,30,31,34,35,37,39,40,43';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>48</strong> miembros: 33 <strong>control</strong><br>0,1,2,4,6,7,8,11,12,13,14,17,20,21,22,24,26,27,28,29,32,33,36,38,41,42,44,45,46,47,48,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 18 <br>3,5,9,10,15,16,18,19,23,25,30,31,34,35,37,39,40,43';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>48</strong> miembros: 33 <strong>control</strong><br>0,1,2,4,6,7,8,11,12,13,14,17,20,21,22,24,26,27,28,29,32,33,36,38,41,42,44,45,46,47,48,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 18 <br>3,5,9,10,15,16,18,19,23,25,30,31,34,35,37,39,40,43';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>48</strong> miembros: 33 <strong>control</strong><br>0,1,2,4,6,7,8,11,12,13,14,17,20,21,22,24,26,27,28,29,32,33,36,38,41,42,44,45,46,47,48,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260821 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 18 <br>3,5,9,10,15,16,18,19,23,25,30,31,34,35,37,39,40,43';}
}
